@@ -35,8 +35,8 @@ HClustOptions::HClustOptions(Rcpp::RObject control) {
    vpSelectTest = DEFAULT_VP_SELECT_TEST;
    nodesVisitedLimit = DEFAULT_NODES_VISITED_LIMIT;
    thresholdGini = DEFAULT_THRESHOLD_GINI;
-   useVpTree = DEFAULT_USEVPTREE;
-   useMST = DEFAULT_USEMST;
+   // useVpTree = DEFAULT_USEVPTREE;
+   // useMST = DEFAULT_USEMST;
 
    if (!Rf_isNull((SEXP)control)) {
       Rcpp::List control2(control);
@@ -88,13 +88,13 @@ HClustOptions::HClustOptions(Rcpp::RObject control) {
          thresholdGini = (double)Rcpp::as<Rcpp::NumericVector>(control2["thresholdGini"])[0];
       }
 
-      if (control2.containsElementNamed("useVpTree")) {
-         useVpTree = (bool)Rcpp::as<Rcpp::LogicalVector>(control2["useVpTree"])[0];
-      }
+      // if (control2.containsElementNamed("useVpTree")) {
+      //    useVpTree = (bool)Rcpp::as<Rcpp::LogicalVector>(control2["useVpTree"])[0];
+      // }
 
-      if (control2.containsElementNamed("useMST")) {
-         useMST = (bool)Rcpp::as<Rcpp::LogicalVector>(control2["useMST"])[0];
-      }
+      // if (control2.containsElementNamed("useMST")) {
+      //    useMST = (bool)Rcpp::as<Rcpp::LogicalVector>(control2["useMST"])[0];
+      // }
    }
 
    if (thresholdGini < 0.0 || thresholdGini > 1.0) {
@@ -154,9 +154,9 @@ Rcpp::NumericVector HClustOptions::toR() const
       Rcpp::_["vpSelectCand"]       = vpSelectCand,
       Rcpp::_["vpSelectTest"]       = vpSelectTest,
       Rcpp::_["nodesVisitedLimit"]  = nodesVisitedLimit,
-      Rcpp::_["thresholdGini"]      = thresholdGini,
-      Rcpp::_["useVpTree"]          = useVpTree,
-      Rcpp::_["useMST"]             = useMST
+      Rcpp::_["thresholdGini"]      = thresholdGini
+      // Rcpp::_["useVpTree"]          = useVpTree,
+      // Rcpp::_["useMST"]             = useMST
    );
 }
 
